get_flag_value

Function get_flag_value 

pub fn get_flag_value(args: &[String], flag: &str) -> Option<String>
Extract the value for a flag from command arguments Returns None if flag not found or if it has no value